import React, { useState } from 'react';
import './assets/calendarcom.css';

function CalendarCom({
  primaryColor = '#008ffd',
  primaryAccentColor = '#cbe8ff',
  backgroundColor = '#d6dae0',
  textColorPrimary = '#1f1f25',
  textColorSecondary = '#999fa6',
}) {
  const [currentDate, setCurrentDate] = useState(new Date());

  const getMonthName = (date) => {
    return date.toLocaleString('default', { month: 'long', year: 'numeric' });
  };

  const handlePreviousMonth = () => {
    setCurrentDate(new Date(currentDate.getFullYear(), currentDate.getMonth() - 1, 1));
  };

  const handleNextMonth = () => {
    setCurrentDate(new Date(currentDate.getFullYear(), currentDate.getMonth() + 1, 1));
  };

  const getStartOfMonth = (date) => {
    return new Date(date.getFullYear(), date.getMonth(), 1);
  };

  const getEndOfMonth = (date) => {
    return new Date(date.getFullYear(), date.getMonth() + 1, 0);
  };

  const getStartOfWeek = (date) => {
    const day = date.getDay();
    const diff = date.getDate() - day + (day === 0 ? -6 : 1);
    return new Date(date.setDate(diff));
  };

  const getEndOfWeek = (date) => {
    const startOfWeek = getStartOfWeek(date);
    return new Date(startOfWeek.getFullYear(), startOfWeek.getMonth(), startOfWeek.getDate() + 6);
  };

  const generateCalendar = () => {
    const startOfMonth = getStartOfMonth(currentDate);
    const endOfMonth = getEndOfMonth(currentDate);
    const startOfCalendar = getStartOfWeek(new Date(startOfMonth));
    const endOfCalendar = getEndOfWeek(new Date(endOfMonth));

    const calendar = [];
    let day = new Date(startOfCalendar);

    while (day <= endOfCalendar) {
      const isSunday = day.getDay() === 0;
      const isCurrentDay = day.toDateString() === new Date().toDateString();
      const isCurrentSunday = isSunday && isCurrentDay;

      calendar.push(
        <button
          key={day.toDateString()}
          className={`date ${day.getMonth() === currentDate.getMonth() ? '' : 'faded'} ${isSunday ? 'sunday' : ''} ${isCurrentDay ? 'current-day' : ''} ${isCurrentSunday ? 'current-sunday' : ''}`}
        >
          {day.getDate()}
        </button>
      );
      day.setDate(day.getDate() + 1);
    }

    return calendar;
  };

  return (
    <div className="datepicker" style={{
      '--c-theme-primary': primaryColor,
      '--c-theme-primary-accent': primaryAccentColor,
      '--c-bg-primary': backgroundColor,
      '--c-text-primary': textColorPrimary,
      '--c-text-secondary': textColorSecondary,
    }}>
      <div className="datepicker-top">
        <div className="month-selector">
          <button className="arrow" onClick={handlePreviousMonth}>
            <i className="material-icons">chevron_left</i>
          </button>
          <span className="month-name">{getMonthName(currentDate)}</span>
          <button className="arrow" onClick={handleNextMonth}>
            <i className="material-icons">chevron_right</i>
          </button>
        </div>
      </div>
      <div className="datepicker-calendar">
        <span className="day">Mo</span>
        <span className="day">Tu</span>
        <span className="day">We</span>
        <span className="day">Th</span>
        <span className="day">Fr</span>
        <span className="day">Sa</span>
        <span className="day">Su</span>
        {generateCalendar()}
      </div>
    </div>
  );
}

export default CalendarCom;
